% fresp.m - frequency response of an IIR filter at a frequency vector w
%
% Usage: H = fresp(b,a,w)                (equivalent to w0=0)
%        H = fresp(b,a,w,w0)             (recentered at w=w0)

%
% b = numerator polynomial,  b = [b0,b1,...,bL], (entered as row or column)
% a = denominator polynomial, a = [1,a1,...,aM], (entered as row or column)
% w = arbitrary vector of frequencies in rads/sample (row or column)
% w0 = center frequency in rads/sample, (default w0=0)
%
% H = frequency response H(w) = B(w)/A(w), has same size as w
%
% notes: it optionally applies the lowpass-to-bandpass bilinear transformation
%              zhat = z.*(c0-z)./(1-c0*z), c0=cos(w0), 
%        to recenter a lowpass frequency response at w=w0
%
% uses ztran, see also dtft

function H = fresp(b,a,w,w0)

if nargin==0, help fresp; return; end
if nargin==3, w0=0; end

c0 = cos(w0);                             

z = exp(j*w);

if c0==1 | c0==-1,                       % assumes cos(0)=1 and cos(pi)=-1 exactly (true for versions 6 & 7)
   zhat = c0*z;                          % zhat=z, or, zhat=-z, for lowpass or highpass
else
   zhat = z.*(c0-z)./(1-c0*z);           % lowpass-to-bandpass transformation
end

H = ztran(b,zhat)./ztran(a,zhat);        % shifted frequency response to w=w0


